@@ -21,7 +21,7 @@
 struct s_dico;
 struct s_strlist;
 
-int btrfs_mkfs(struct s_dico *d, char *partition);
+int btrfs_mkfs(struct s_dico *d, char *partition, char *fsoptions);
 int btrfs_getinfo(struct s_dico *d, char *devname);
 int btrfs_mount(char *partition, char *mntbuf, char *fsbuf, int flags, char *mntinfo);
 int btrfs_umount(char *partition, char *mntbuf);
@@ -29,25 +29,33 @@ int btrfs_check_support_for_features(u64 compat, u64 incompat, u64 ro_compat);
 int btrfs_get_reqmntopt(char *partition, struct s_strlist *reqopt, struct s_strlist *badopt);
 int btrfs_test(char *devname);
 
-// compat flags: official definition from linux-3.4/fs/btrfs/ctree.h
+// compat flags: official definition from linux-3.14/fs/btrfs/ctree.h
 #define BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF    (1ULL << 0)
 #define BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL   (1ULL << 1)
 #define BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS     (1ULL << 2)
 #define BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO     (1ULL << 3)
 #define BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2   (1ULL << 4)
 #define BTRFS_FEATURE_INCOMPAT_BIG_METADATA     (1ULL << 5)
-
+#define BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF    (1ULL << 6)
+#define BTRFS_FEATURE_INCOMPAT_RAID56           (1ULL << 7)
+#define BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA  (1ULL << 8)
+#define BTRFS_FEATURE_INCOMPAT_NO_HOLES         (1ULL << 9)
 
 // compat flags: btrfs features that this fsarchiver version supports
 #define FSA_BTRFS_FEATURE_COMPAT_SUPP           0ULL
 #define FSA_BTRFS_FEATURE_COMPAT_RO_SUPP        0ULL
-#define FSA_BTRFS_FEATURE_INCOMPAT_SUPP         \
-        (BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF | \
-         BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL | \
-         BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS | \
-         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO | \
-         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2 | \
-         BTRFS_FEATURE_INCOMPAT_BIG_METADATA)
+#define FSA_BTRFS_FEATURE_INCOMPAT_SUPP                 \
+        (BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF |         \
+         BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL |        \
+         BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS |          \
+         BTRFS_FEATURE_INCOMPAT_BIG_METADATA |          \
+         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO |          \
+         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2 |        \
+         BTRFS_FEATURE_INCOMPAT_RAID56 |                \
+         BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF |         \
+         BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA |       \
+         BTRFS_FEATURE_INCOMPAT_NO_HOLES)
+
 
 // disk layout definitions
 #define BTRFS_SUPER_MAGIC 0x9123683E
