@@ -34,7 +34,7 @@
 #include "strlist.h"
 #include "error.h"
 
-int xfs_mkfs(cdico *d, char *partition)
+int xfs_mkfs(cdico *d, char *partition, char *fsoptions)
 {
     char command[2048];
     char buffer[2048];
@@ -48,6 +48,9 @@ int xfs_mkfs(cdico *d, char *partition)
     }
     
     memset(options, 0, sizeof(options));
+
+    strlcatf(options, sizeof(options), " %s ", fsoptions);
+
     if (dico_get_string(d, 0, FSYSHEADKEY_FSLABEL, buffer, sizeof(buffer))==0 && strlen(buffer)>0)
         strlcatf(options, sizeof(options), " -L '%.12s' ", buffer);
     
